@@ -16,9 +16,11 @@ class Git(object):
 
         * |appteardown| if `remote_url` is set to ``None`` but a new clone is necessary
 
+    :param mbranch: The repository's main branch. Is set to `master` when left to ``None``
+
     '''
 
-    def __init__(self, m, local, remote_url=None):
+    def __init__(self, m, local, remote_url=None, mbranch=None):
         super().__init__()
 
         from ..util.locations import search_location
@@ -27,6 +29,8 @@ class Git(object):
         self.m = check_m(m)
         self.__local = search_location(local, create_in=local)
         self.__remote_url = remote_url
+        if not mbranch: mbranch = 'master'
+        self.__mbranch = mbranch
 
         if self.m(
             'checking for git repo',
@@ -70,11 +74,34 @@ class Git(object):
     @property
     def commit(self):
         '''
-        :returns: The current commit
+        :param tag: Checks out specified commit. If set to ``None`` the latest commit will be checked out
+        :returns: A list of all commits, descending
         '''
 
-        return self._log(num=1, format='%H').get('out')
+        commit = self._log(num=-1, format='%H')
+        if commit.get('returncode') == 0: return commit.get('stdout')
 
+    @commit.setter
+    def commit(self, commit):
+        '''
+        .. seealso:: :attr:`commit`
+        '''
+
+        c = self.commit
+        if c:
+            if not commit: commit = c[0]
+            if commit in c: self._checkout(treeish=commit)
+
+    @property
+    def short_commit(self):
+        '''
+        :returns: A list of all commits, descending
+
+        .. seealso:: :attr:`commit`
+        '''
+
+        commit = self._log(num=-1, format='%h')
+        if commit.get('returncode') == 0: return commit.get('stdout')
 
     @property
     def log(self):
@@ -133,10 +160,9 @@ class Git(object):
         .. seealso:: :attr:`branch`
         '''
 
-
-        if not branch: branch = 'master'
-        tracking = '' if branch in self._get_branch(remotes=True).get('out') else '-B '
-        self._checkout(treeish='%s%s' %(tracking, branch))
+        if not branch: branch = self.__mbranch
+        tracking = '' if branch in self._get_branch(remotes=True).get('out') else '-B'
+        self._checkout(treeish='%s %s' %(tracking, branch))
 
     @property
     def tag(self):
@@ -149,8 +175,8 @@ class Git(object):
             'getting git tags',
             cmdd=dict(cmd='git tag -l --sort="version:refname"', cwd=self.local),
             verbose=False,
-        ).get('stdout')
-        if tag: return tag
+        )
+        if tag.get('returncode') == 0: return tag.get('stdout')
 
     @tag.setter
     def tag(self, tag):
@@ -158,10 +184,10 @@ class Git(object):
         .. seealso:: :attr:`tag`
         '''
 
-        if not tag:
-            t = self.tag
-            tag = t[-1] if t else None
-        if tag: self._checkout(treeish=tag)
+        t = self.tag
+        if t:
+            if not tag: tag = t[-1]
+            if tag in t: self._checkout(treeish=tag)
 
     @property
     def cleanup(self):
@@ -215,11 +241,7 @@ class Git(object):
             )
 
             self.branch = old_branch
-
-        pull = self.m('pulling remote changes', cmdd=dict(cmd='git pull --tags', cwd=self.local), critical=False)
-
-        if 'CONFLICT' in pull.get('out'): self.m('you have a merge conflict with your remote repository!', state=True, more=pull)
-
+            pull = self._pull
         return dict(changes=changes, pull=pull)
 
     @property
@@ -292,3 +314,16 @@ class Git(object):
             cmdd=dict(cmd='git checkout %s' %(treeish), cwd=self.local),
             verbose=False
         )
+
+    def _pull(self):
+        '''
+        Helper function to pull from remote
+        '''
+
+        pull = self.m(
+            'pulling remote changes',
+            cmdd=dict(cmd='git pull --tags', cwd=self.local),
+            critical=False
+        )
+        if 'CONFLICT' in pull.get('out'): self.m('you have a merge conflict with your remote repository!', state=True, more=pull)
+        return pull
