@@ -15,7 +15,6 @@ def get_locations():
     * 'call_dir': Where you called the first Python script from. (``argv[0]``)
     * 'conf_dir': The :envvar:`XDG_CONFIG_HOME`-directory + ``photon`` (:file:`~/.config/photon`)
     * 'data_dir': The :envvar:`XDG_DATA_HOME`-directory + ``photon`` (:file:`~/.local/share/photon`)
-    * 'backup_dir': The `data_dir` + ``backups``
 
     .. note::
 
@@ -35,8 +34,7 @@ def get_locations():
         'home_dir': home_dir,
         'call_dir': _path.dirname(_path.abspath(_argv[0])),
         'conf_dir': conf_dir,
-        'data_dir': data_dir,
-        'backup_dir': _path.join(data_dir, 'backups')
+        'data_dir': data_dir
     }
 
 def make_locations(locations=None, verbose=True):
@@ -109,12 +107,16 @@ def change_location(src, tgt, move=False, verbose=True):
     '''
     Copies/moves/deletes locations
 
-    :param src: source location where to copy from
-    :param tgt: target location where to copy to
-    :param move: deletes original after copy (a.k.a. move)
-    :param verbose: show warnings
+    :param src: Source location where to copy from
+    :param tgt: Target location where to copy to
 
-    .. note:: set `tgt` explicit to ``None`` and `move` to ``True`` to delete locations. (be careful!!1!)
+        * To backup `src`, set `tgt` explicitly to ``True``. `tgt` will be set to `src` + '_backup_' + :func:`util.system.get_timestamp` then
+
+    :param move: Deletes original location after copy (a.k.a. move)
+
+        * To delete `src` , set `tgt` explicitly to ``False`` and `move` to ``True`` (be careful!!1!)
+
+    :param verbose: Show warnings
     '''
 
     from os import path as _path, listdir as _listdir, remove as _remove
@@ -122,13 +124,36 @@ def change_location(src, tgt, move=False, verbose=True):
     from .system import shell_notify
 
     if _path.exists(src):
-        if _path.isfile(src):
-            _copy2(src, search_location(tgt, create_in=_path.dirname(tgt), verbose=verbose))
-        else:
-            for l in _listdir(src): change_location(_path.abspath(_path.join(src, l)), _path.abspath(_path.join(tgt, l)))
-
-        if move: _rmtree(src) if _path.isdir(src) else _remove(src)
+        if tgt:
+            if _path.isfile(src):
+                _copy2(src, search_location(tgt, create_in=_path.dirname(tgt), verbose=verbose))
+            else:
+                for l in _listdir(src): change_location(_path.abspath(_path.join(src, l)), _path.abspath(_path.join(tgt, l)))
+        if move: _rmtree(src) if _path.isdir(src) and not _path.islink(src) else _remove(src)
         if verbose: shell_notify(
             '%s location' %('deleted' if not tgt and move else 'moved' if move else 'copied'),
             more=dict(src=src, tgt=tgt)
         )
+
+def backup_location(src, loc=None):
+    '''
+    Writes Backups of locations
+
+    :param src: The source file/folder to backup
+    :param loc: The target folder to backup into
+
+        The backup will be called `src` + :func:`util.system.get_timestamp`.
+        * If `loc` left to none, the backup gets written in the same folder like `src` resides in
+        * Otherwise the specified path will be used.
+    '''
+
+    from os import path as _path, sep as _sep
+    from .system import get_timestamp
+
+    src = _path.realpath(src)
+    if not loc or not loc.startswith(_sep): loc = _path.dirname(src)
+
+    pth = _path.join(_path.basename(src), _path.realpath(loc))
+    out = '%s_backup_%s' %(_path.basename(src), get_timestamp())
+
+    change_location(src, search_location(out, create_in=pth))
